/*
 * PlotSquared, a land and world management plugin for Minecraft.
 * Copyright (C) IntellectualSites <https://intellectualsites.com>
 * Copyright (C) IntellectualSites team and contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.plotsquared.core.util;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.MODULE;
import static java.lang.annotation.ElementType.PACKAGE;
import static java.lang.annotation.ElementType.RECORD_COMPONENT;
import static java.lang.annotation.ElementType.TYPE;

/**
 * @since 6.2.2
 */
@AnnotationHelper.ApiDescription(info = "An internal class for custom annotations." +
        "This is in no form part of the API and is subject to change at any time.")
public final class AnnotationHelper {

    private AnnotationHelper() {
    }

    @Documented
    @Retention(RetentionPolicy.CLASS)
    @Target(value = {METHOD, PACKAGE, MODULE, RECORD_COMPONENT, TYPE})
    public @interface ApiDescription {
        /**
         * Returns additional information how to use a class for the API
         *
         * @return the version string
         * @since 6.2.2
         */
        String info() default "";
    }

}
